package com.ruoyi.system.controller;


import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.ActSupplies;
import com.ruoyi.system.domain.ActSuppliesDetails;
import com.ruoyi.system.service.IActSuppliesDetailsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 物料细分类管理Controller
 * 
 * @author ruoyi
 * @date 2023-07-11
 */
@RestController
@RequestMapping("/ActSuppliesDetails/ActSuppliesDetails")
public class ActSuppliesDetailsController extends BaseController
{
    @Autowired
    private IActSuppliesDetailsService actSuppliesDetailsService;

    /**
     * 查询上级分类
     * */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:savesid')")
    @GetMapping("/savesid")
    @ResponseBody
    public TableDataInfo saveSid(){

        List<ActSupplies> options = actSuppliesDetailsService.saveSid();

        return getDataTable(options);

    }

    /**
     * 查询物料细分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:list')")
    @GetMapping("/list")
    public TableDataInfo list(ActSuppliesDetails actSuppliesDetails)
    {
        startPage();
        List<ActSuppliesDetails> list = actSuppliesDetailsService.selectActSuppliesDetailsList(actSuppliesDetails);
        return getDataTable(list);
    }

    /**
     * 导出物料细分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:export')")
    @Log(title = "物料细分类管理", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ActSuppliesDetails actSuppliesDetails)
    {
        List<ActSuppliesDetails> list = actSuppliesDetailsService.selectActSuppliesDetailsList(actSuppliesDetails);
        ExcelUtil<ActSuppliesDetails> util = new ExcelUtil<ActSuppliesDetails>(ActSuppliesDetails.class);
        return util.exportExcel(list, "物料细分类管理数据");
    }

    /**
     * 获取物料细分类管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(actSuppliesDetailsService.selectActSuppliesDetailsById(id));
    }

    /**
     * 新增物料细分类管理
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:add')")
    @Log(title = "物料细分类管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ActSuppliesDetails actSuppliesDetails)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        actSuppliesDetails.setCreateBy(user.getUserName());

        return toAjax(actSuppliesDetailsService.insertActSuppliesDetails(actSuppliesDetails));
    }

    /**
     * 修改物料细分类管理
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:edit')")
    @Log(title = "物料细分类管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ActSuppliesDetails actSuppliesDetails)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        actSuppliesDetails.setUpdateBy(user.getUserName());

        return toAjax(actSuppliesDetailsService.updateActSuppliesDetails(actSuppliesDetails));
    }

    /**
     * 删除物料细分类管理
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:remove')")
    @Log(title = "物料细分类管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {

        return toAjax(actSuppliesDetailsService.deleteActSuppliesDetailsByIds(ids));

    }

    /**
     * 启用物料细分类管理
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:enable')")
    @GetMapping("/enable/{id}")
    public AjaxResult setEnable(@PathVariable("id") Long id)
    {
        System.out.println("开始处理【启用物料细分类管理】的请求，参数：{}"+ id);
        actSuppliesDetailsService.setEnable(id);
        return AjaxResult.success();
    }

    /**
     * 禁用物料细分类管理
     */
    @PreAuthorize("@ss.hasPermi('ActSuppliesDetails:ActSuppliesDetails:Disable')")
    @GetMapping("/disable/{id}")
    public AjaxResult setDisable(@PathVariable("id") Long id)
    {
        System.out.println("开始处理【禁用物料细分类管理】的请求，参数：{}"+ id);
        actSuppliesDetailsService.setDisable(id);
        return AjaxResult.success();

    }
}
