package com.ruoyi.system.service.impl;


import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.ActSupplies;
import com.ruoyi.system.domain.ActSuppliesDetails;
import com.ruoyi.system.mapper.ActSuppliesDetailsMapper;
import com.ruoyi.system.service.IActSuppliesDetailsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 物料细分类管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-11
 */
@Service
public class ActSuppliesDetailsServiceImpl implements IActSuppliesDetailsService
{
    @Autowired
    private ActSuppliesDetailsMapper actSuppliesDetailsMapper;

    /**
     * 查询物料细分类管理
     * 
     * @param id 物料细分类管理ID
     * @return 物料细分类管理
     */
    @Override
    public ActSuppliesDetails selectActSuppliesDetailsById(Long id)
    {
        return actSuppliesDetailsMapper.selectActSuppliesDetailsById(id);
    }

    /**
     * 查询物料细分类管理列表
     * 
     * @param actSuppliesDetails 物料细分类管理
     * @return 物料细分类管理
     */
    @Override
    public List<ActSuppliesDetails> selectActSuppliesDetailsList(ActSuppliesDetails actSuppliesDetails)
    {
        return actSuppliesDetailsMapper.selectActSuppliesDetailsList(actSuppliesDetails);
    }

    /**
     * 新增物料细分类管理
     * 
     * @param actSuppliesDetails 物料细分类管理
     * @return 结果
     */
    @Override
    public int insertActSuppliesDetails(ActSuppliesDetails actSuppliesDetails)
    {
        actSuppliesDetails.setCreateTime(DateUtils.getNowDate());
        return actSuppliesDetailsMapper.insertActSuppliesDetails(actSuppliesDetails);
    }

    /**
     * 修改物料细分类管理
     * 
     * @param actSuppliesDetails 物料细分类管理
     * @return 结果
     */
    @Override
    public int updateActSuppliesDetails(ActSuppliesDetails actSuppliesDetails)
    {
        actSuppliesDetails.setUpdateTime(DateUtils.getNowDate());
        return actSuppliesDetailsMapper.updateActSuppliesDetails(actSuppliesDetails);
    }

    /**
     * 批量删除物料细分类管理
     * 
     * @param ids 需要删除的物料细分类管理ID
     * @return 结果
     */
    @Override
    public int deleteActSuppliesDetailsByIds(Long[] ids)
    {
        return actSuppliesDetailsMapper.deleteActSuppliesDetailsByIds(ids);
    }

    /**
     * 删除物料细分类管理信息
     * 
     * @param id 物料细分类管理ID
     * @return 结果
     */
    @Override
    public int deleteActSuppliesDetailsById(Long id)
    {
        return actSuppliesDetailsMapper.deleteActSuppliesDetailsById(id);
    }

    @Override
    public List<ActSupplies> saveSid() {
        return actSuppliesDetailsMapper.saveSid();
    }
    @Override
    public void setEnable(Long id) {
        updateStatusById(id,0);
    }

    @Override
    public void setDisable(Long id) {
        updateStatusById(id,1);
    }


    private void updateStatusById(Long id, Integer status){
        String[] statusText={"禁用","启用"};

        //判断查询结果是否为空
        ActSuppliesDetails queryResult = actSuppliesDetailsMapper.selectActSuppliesDetailsById(id);

        if(queryResult ==null) {
            String message =statusText[status] + "物料细分类管理失败，尝试访问的数据不存在";
            System.out.println(message);
            throw new RuntimeException(message);
        }

        //判断以上查询结果中的status是否与参数status相同
        if(queryResult.getStatus().equals(status)){
            String message = statusText[status] + "物料细分类管理失败，当前物料细分类管理已经处理" +statusText[status] + "状态！";
            System.out.println(message);
            throw new RuntimeException(message);
        }
        ActSuppliesDetails actSuppliesDetails=new ActSuppliesDetails();
        actSuppliesDetails.setId(id);
        actSuppliesDetails.setStatus(status);

        int rows = actSuppliesDetailsMapper.updateActSuppliesDetails(actSuppliesDetails);
        if (rows != 1) {
            String message = statusText[status] + "物料细分类管理失败，服务器忙请再次重试";
            System.out.println(message);
            throw new RuntimeException(message);
        }
    }
}
